==> richfaces-showcase-4.5.4.Final-sources.jar: src/test/integration/org/richfaces/showcase/status/ITestReferencedUsage.java <==
/*******************************************************************************
 * JBoss, Home of Professional Open Source
 * Copyright 2010-2014, Red Hat, Inc. and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 *******************************************************************************/
package org.richfaces.showcase.status;

import org.jboss.arquillian.graphene.page.Page;
import org.junit.Test;
import org.junit.experimental.categories.Category;
import org.richfaces.showcase.status.page.TestReferencedUsagePage;

import category.FailingOnPhantomJS;

/**
 * @author <a href="mailto:jhuska@redhat.com">Juraj Huska</a>
 * @version $Revision$
 */
public class ITestReferencedUsage extends TestUsage {

    @Page
    private TestReferencedUsagePage page;

    @Test
    @Category(FailingOnPhantomJS.class)
    public void testUserNameAndAjaxRequestProgressImage() {
        page.getUserNameInput().sendKeys("a");
        assertProgressPictureAppearsOnAjaxRequest(page.getFirstAjaxRequestProgressImage());
    }

    @Test
    public void testAddressAndAjaxRequestProgressImage() {
        page.getAddressInput().sendKeys("a");
        assertProgressPictureAppearsOnAjaxRequest(page.getSecondAjaxRequestProgressImage());
    }

}

==> richfaces-showcase-4.5.9.Final-sources.jar: src/test/integration/org/richfaces/showcase/status/ITestReferencedUsage.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010-2014, Red Hat, Inc. and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.richfaces.showcase.status;

import org.jboss.arquillian.graphene.page.Page;
import org.junit.Test;
import org.richfaces.showcase.status.page.TestReferencedUsagePage;

/**
 * @author <a href="mailto:jhuska@redhat.com">Juraj Huska</a>
 */
public class ITestReferencedUsage extends TestUsage {

    @Page
    private TestReferencedUsagePage page;

    @Test
    public void testAddressAndAjaxRequestProgressImage() {
        assertProgressPictureAppearsOnAjaxRequest(sendKeysToInputAction(page.getAddressInput()), 1);
    }

    @Test
    public void testUserNameAndAjaxRequestProgressImage() {
        assertProgressPictureAppearsOnAjaxRequest(sendKeysToInputAction(page.getUserNameInput()), 0);
    }
}
